@@ -14,6 +14,8 @@ function _aws_cdk_aws_kms_AliasAttributes(p) {
         _aws_cdk_aws_kms_IKey(p.aliasTargetKey);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_kms_IAlias(p) {
+}
 function _aws_cdk_aws_kms_CfnReplicaKeyProps(p) {
     if (p == null)
         return;
@@ -22,18 +24,8 @@ function _aws_cdk_aws_kms_CfnReplicaKeyProps(p) {
         require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_kms_IAlias(p) {
-}
 function _aws_cdk_aws_kms_ViaServicePrincipal(p) {
 }
-function _aws_cdk_aws_kms_CfnKeyProps(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    if (!visitedObjects.has(p.tags))
-        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
-    visitedObjects.delete(p);
-}
 function _aws_cdk_aws_kms_AliasProps(p) {
     if (p == null)
         return;
@@ -42,6 +34,14 @@ function _aws_cdk_aws_kms_AliasProps(p) {
         _aws_cdk_aws_kms_IKey(p.targetKey);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_kms_CfnKeyProps(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.tags))
+        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_aws_kms_CfnAlias(p) {
 }
 function _aws_cdk_aws_kms_CfnReplicaKey(p) {
@@ -83,5 +83,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_kms_KeySpec, _aws_cdk_aws_kms_KeyUsage, _aws_cdk_aws_kms_KeyLookupOptions, _aws_cdk_aws_kms_CfnAliasProps, _aws_cdk_aws_kms_AliasAttributes, _aws_cdk_aws_kms_CfnReplicaKeyProps, _aws_cdk_aws_kms_IAlias, _aws_cdk_aws_kms_ViaServicePrincipal, _aws_cdk_aws_kms_CfnKeyProps, _aws_cdk_aws_kms_AliasProps, _aws_cdk_aws_kms_CfnAlias, _aws_cdk_aws_kms_CfnReplicaKey, _aws_cdk_aws_kms_CfnKey, _aws_cdk_aws_kms_IKey, _aws_cdk_aws_kms_KeyProps, _aws_cdk_aws_kms_Alias, _aws_cdk_aws_kms_Key };
+module.exports = { print, _aws_cdk_aws_kms_KeySpec, _aws_cdk_aws_kms_KeyUsage, _aws_cdk_aws_kms_KeyLookupOptions, _aws_cdk_aws_kms_CfnAliasProps, _aws_cdk_aws_kms_AliasAttributes, _aws_cdk_aws_kms_IAlias, _aws_cdk_aws_kms_CfnReplicaKeyProps, _aws_cdk_aws_kms_ViaServicePrincipal, _aws_cdk_aws_kms_AliasProps, _aws_cdk_aws_kms_CfnKeyProps, _aws_cdk_aws_kms_CfnAlias, _aws_cdk_aws_kms_CfnReplicaKey, _aws_cdk_aws_kms_CfnKey, _aws_cdk_aws_kms_IKey, _aws_cdk_aws_kms_KeyProps, _aws_cdk_aws_kms_Alias, _aws_cdk_aws_kms_Key };
 module.exports.DeprecationError = DeprecationError;
